@@ -1,4 +1,4 @@
-# Copyright 2024 DARWIN EU®
+# Copyright 2025 DARWIN EU®
 #
 # This file is part of CDMConnector
 #
@@ -94,6 +94,157 @@ readCohortSet <- function(path) {
   return(cohortsToCreate)
 }
 
+extractCodesetIds <- function(x) {
+  if (is.list(x)) {
+    codes <- x[names(x) == "CodesetId"]
+    return(c(unlist(codes), unlist(purrr::map(x, extractCodesetIds))))
+  }
+  return(NULL)
+}
+
+createCodelistDataframe <- function(cohortSet) {
+
+  purrr::map2(cohortSet$cohort_definition_id, cohortSet$cohort, function(cohort_definition_id, ch) {
+
+    df1 <- dplyr::tibble(
+      cohort_definition_id = cohort_definition_id,
+      codelist_id = purrr::map_int(ch[["ConceptSets"]], "id"),
+      codelist_name = purrr::map_chr(ch[["ConceptSets"]], "name")
+    )
+
+    df2 <- dplyr::bind_rows(
+      dplyr::tibble(
+        codelist_id = unname(extractCodesetIds(ch[["PrimaryCriteria"]])),
+        codelist_type = "index event"
+      ),
+      dplyr::tibble(
+        codelist_id = unname(extractCodesetIds(ch[["InclusionRules"]])),
+        codelist_type = "inclusion criteria"
+      )
+    ) |> dplyr::filter(!is.na(.data$codelist_id))
+
+    return(dplyr::inner_join(df1, df2, by = "codelist_id"))
+  }) |>
+    dplyr::bind_rows()
+}
+
+
+extractConceptsFromConceptSetList <- function(conceptSets) {
+  results <- list()
+  for (entry in conceptSets) {
+    concept_set_id <- entry$id
+    if (!is.null(entry$expression$items)) {
+      for (item in entry$expression$items) {
+        concept_id <- item$concept$CONCEPT_ID
+        is_excluded <- ifelse(!is.null(item$isExcluded), item$isExcluded, FALSE)
+        include_descendants <- ifelse(!is.null(item$includeDescendants), item$includeDescendants, FALSE)
+
+        results <- append(results, list(dplyr::tibble(
+          codelist_id = concept_set_id,
+          concept_id = concept_id,
+          is_excluded = is_excluded,
+          include_descendants = include_descendants
+        )))
+      }
+    }
+  }
+
+  return(dplyr::bind_rows(results))
+}
+
+createAtlasCohortCodelistReference <- function(cdm, cohortSet) {
+  codelistDf <- createCodelistDataframe(cohortSet)
+
+  codes <- cohortSet |>
+    dplyr::select("cohort_definition_id", "cohort") |>
+    dplyr::mutate(df = purrr::map(.data$cohort, ~extractConceptsFromConceptSetList(.$ConceptSets))) |>
+    dplyr::select(1, 3) |>
+    tidyr::unnest(cols = 2)
+
+
+  df <- dplyr::left_join(codelistDf, codes, by = c("cohort_definition_id", "codelist_id"))
+
+  # upload concept data to the database ----
+  tempName <- omopgenerics::uniqueTableName()
+
+  DBI::dbWriteTable(cdmCon(cdm),
+                    name = .inSchema(cdmWriteSchema(cdm), tempName, dbms = dbms(cdmCon(cdm))),
+                    value = df,
+                    overwrite = TRUE)
+
+  on.exit({
+    if (DBI::dbIsValid(cdmCon(cdm))) {
+      DBI::dbRemoveTable(cdmCon(cdm), name = .inSchema(cdmWriteSchema(cdm), tempName, dbms = dbms(cdmCon(cdm))))
+    }},
+    add = TRUE
+  )
+
+  if (any(df$include_descendants)) {
+    checkmate::assertTRUE("concept_ancestor" %in% names(cdm))
+  }
+
+  # realize full list of concepts ----
+  concepts <- dplyr::tbl(cdmCon(cdm), .inSchema(cdmWriteSchema(cdm), tempName, dbms = dbms(cdmCon(cdm)))) %>%
+    dplyr::rename_all(tolower)
+
+  if (any(df$include_descendants)) {
+    concepts <- concepts  %>%
+      dplyr::filter(.data$include_descendants == TRUE) %>%
+      dplyr::inner_join(cdm$concept_ancestor, by = c("concept_id" = "ancestor_concept_id")) %>%
+      dplyr::select(
+        "cohort_definition_id", "codelist_id",
+        "codelist_name", "codelist_type",
+        "concept_id" = "descendant_concept_id",
+        "is_excluded"
+      ) %>%
+      dplyr::union_all(
+        dplyr::select(concepts,
+                      "cohort_definition_id", "codelist_id",
+                      "codelist_name", "codelist_type",
+                      "concept_id", "is_excluded"
+        )
+      )
+  }
+
+  codelistTableName <- omopgenerics::uniqueTableName("codelist_")
+
+  analyzeParam <- ifelse(dbms(cdmCon(cdm)) == "spark", FALSE, TRUE)
+  cohortCodelistRef <- concepts %>%
+    dplyr::filter(.data$is_excluded == FALSE) %>%
+    # Note that concepts that are not in the vocab will be silently ignored
+    dplyr::inner_join(dplyr::select(cdm$concept, "concept_id", "domain_id"), by = "concept_id") %>%
+    dplyr::select(
+      "cohort_definition_id",
+      "codelist_name",
+      "codelist_type",
+      "concept_id"
+    ) |>
+    dplyr::distinct()
+
+  writeSchema <- unname(cdmWriteSchema(cdm)["schema"])
+
+  # dpbply 2.5 workaround for spark
+  if (dbms(cdmCon(cdm)) == "spark") {
+    cohortCodelistRef <- .computeQuery(
+      cohortCodelistRef,
+      temporary = FALSE,
+      name = codelistTableName,
+      overwrite = TRUE,
+      schema = writeSchema)
+  } else {
+    cohortCodelistRef <- dplyr::compute(
+      cohortCodelistRef,
+      temporary = FALSE,
+      name = codelistTableName,
+      overwrite = TRUE,
+      analyze = analyzeParam)
+  }
+
+
+  return(cohortCodelistRef)
+}
+
+
 #' Generate a cohort set on a cdm object
 #'
 #' @description
@@ -392,6 +543,7 @@ generateCohortSet <- function(cdm,
       # issue with date add translation on spark
       sql <- stringr::str_replace_all(sql, "date_add", "dateadd")
       sql <- stringr::str_replace_all(sql, "DATE_ADD", "DATEADD")
+      sql <- stringr::str_replace_all(sql, "TRUNCATE TABLE", "DELETE FROM")
     }
 
     sql <- stringr::str_replace_all(sql, "\\s+", " ")
@@ -472,10 +624,12 @@ generateCohortSet <- function(cdm,
     cohort_definition_id = as.integer(.data$cohort_definition_id),
     cohort_name = as.character(.data$cohort_name))
 
+  cohortCodelistRef <- createAtlasCohortCodelistReference(cdm, cohortSet)
   cdm[[name]] <- omopgenerics::newCohortTable(
     table = cdm[[name]],
     cohortSetRef = cohortSetRef,
-    cohortAttritionRef = cohort_attrition_ref)
+    cohortAttritionRef = cohort_attrition_ref,
+    cohortCodelistRef = cohortCodelistRef)
 
   cli::cli_progress_done()
 
